@@ -2,7 +2,7 @@
 
 ###################################################################################
 # UCK - Ubuntu Customization Kit                                                  #
-# Copyright (C) 2006-2009 UCK Team                                                #
+# Copyright (C) 2006-2010 UCK Team                                                #
 #                                                                                 #
 # UCK is free software: you can redistribute it and/or modify                     #
 # it under the terms of the GNU General Public License as published by            #
@@ -38,9 +38,12 @@ function unmount_directory()
 function unmount_pseudofilesystems()
 {
 	if [ -n "$REMASTER_DIR" ]; then
-		for i in "$REMASTER_DIR/tmp/.X11-unix" "$REMASTER_DIR"/lib/modules/*/volatile "$REMASTER_DIR"/proc "$REMASTER_DIR"/sys "$REMASTER_DIR"/dev/pts "$REMASTER_DIR"/var/run; do
-			unmount_directory "$i"
-		done
+		unmount_directory "$REMASTER_DIR/tmp"
+		unmount_directory "$REMASTER_DIR/lib/modules/*/volatile"
+		unmount_directory "$REMASTER_DIR/proc"
+		unmount_directory "$REMASTER_DIR/sys"
+		unmount_directory "$REMASTER_DIR/dev/pts"
+		unmount_directory "$REMASTER_DIR/var/run"
 	fi
 }
 
@@ -90,15 +93,20 @@ function unpack_initrd()
 	echo "Unpacking initrd image..."
 	pushd "$INITRD_REMASTER_DIR" || failure "Failed to change directory to $INITRD_REMASTER_DIR, error=$?"
 
-	if [ -e "$ISO_REMASTER_DIR/casper/initrd.gz" ]; then
+	if [ -e "$ISO_REMASTER_DIR/casper/initrd.lz" ]; then
+		INITRD_FILE="$ISO_REMASTER_DIR/casper/initrd.lz"
+		INITRD_PACK=lzma
+	elif [ -e "$ISO_REMASTER_DIR/casper/initrd.gz" ]; then
 		INITRD_FILE="$ISO_REMASTER_DIR/casper/initrd.gz"
+		INITRD_PACK=gzip
 	elif [ -e "$ISO_REMASTER_DIR/install/initrd.gz" ]; then
 		INITRD_FILE="$ISO_REMASTER_DIR/install/initrd.gz"
+		INITRD_PACK=gzip
 	else
-		failure "Can't find initrd.gz file"
+		failure "Can't find initrd.gz nor initrd.lz file"
 	fi
 
-	cat "$INITRD_FILE" | gzip -d | cpio -i
+	cat "$INITRD_FILE" | $INITRD_PACK -d | cpio -i
 	RESULT=$?
 	if [ $RESULT -ne 0 ]; then
 		failure "Failed to unpack $INITRD_FILE to $INITRD_REMASTER_DIR, error=$RESULT"
@@ -115,23 +123,29 @@ function pack_initrd()
 
 	echo "Packing initrd image..."
 	pushd "$INITRD_REMASTER_DIR" || failure "Failed to change directory to $INITRD_REMASTER_DIR, error=$?"
-	find | cpio -H newc -o | gzip >"$REMASTER_HOME/initrd.gz"
+
+	if [ -e "$ISO_REMASTER_DIR/casper/initrd.lz" ]; then
+		INITRD_FILE="$ISO_REMASTER_DIR/casper/initrd.lz"
+		INITRD_PACK=lzma
+	elif [ -e "$ISO_REMASTER_DIR/casper/initrd.gz" ]; then
+		INITRD_FILE="$ISO_REMASTER_DIR/casper/initrd.gz"
+		INITRD_PACK=gzip
+	elif [ -e "$ISO_REMASTER_DIR/install/initrd.gz" ]; then
+		INITRD_FILE="$ISO_REMASTER_DIR/install/initrd.gz"
+		INITRD_PACK=gzip
+	else
+		failure "Can't find where to copy the initrd.packed file"
+	fi
+
+	find | cpio -H newc -o | $INITRD_PACK >"$REMASTER_HOME/initrd.packed"
 	RESULT=$?
 	if [ $RESULT -ne 0 ]; then
-		rm "$REMASTER_HOME/initrd.gz"
-		failure "Failed to compress initird image $INITRD_REMASTER_DIR to $REMASTER_HOME/initrd.gz, error=$RESULT"
+		rm "$REMASTER_HOME/initrd.packed"
+		failure "Failed to compress initird image $INITRD_REMASTER_DIR to $REMASTER_HOME/initrd.packed, error=$RESULT"
 	fi
 	popd
 
-	if [ -e "$ISO_REMASTER_DIR/casper" ]; then
-		INITRD_FILE="$ISO_REMASTER_DIR/casper/initrd.gz"
-	elif [ -e "$ISO_REMASTER_DIR/install" ]; then
-		INITRD_FILE="$ISO_REMASTER_DIR/install/initrd.gz"
-	else
-		failure "Can't find where to copy the initrd.gz file"
-	fi
-
-	mv "$REMASTER_HOME/initrd.gz" "$INITRD_FILE" || failure "Failed to move $NEW_FILES_DIR/initrd.gz to $INITRD_FILE, error=$?"
+	mv "$REMASTER_HOME/initrd.packed" "$INITRD_FILE" || failure "Failed to move $REMASTER_HOME/initrd.packed to $INITRD_FILE, error=$?"
 }
 
 function mount_iso()
@@ -194,6 +208,7 @@ function prepare_rootfs_for_chroot()
 	mount -t sysfs sysfs "$REMASTER_DIR/sys" || echo "Failed to mount $REMASTER_DIR/sys, error=$?"
 	mount -t devpts none "$REMASTER_DIR/dev/pts" || failure "Failed to mount $REMASTER_DIR/dev/pts, error=$?"
 	mount -o bind /var/run "$REMASTER_DIR/var/run"
+	mount -o bind /tmp "$REMASTER_DIR/tmp"
 
 	#create backup of root directory
 	chroot "$REMASTER_DIR" cp -a /root /root.saved || failure "Failed to create backup of /root directory, error=$?"
@@ -214,18 +229,18 @@ function prepare_rootfs_for_chroot()
 		cp -a "$REMASTER_DIR/var/cache/apt/" "$REMASTER_DIR/var/cache/apt.original" || failure "Cannot copy $REMASTER_DIR/var/cache/apt/ to $REMASTER_DIR/var/cache/apt.original, error=$?"
 	fi
 
-	echo "Mounting X11 sockets directory to allow access from customization environment..."
-	mkdir -p "$REMASTER_DIR/tmp/.X11-unix" || failure "Cannot create mount directory $REMASTER_DIR/tmp/.X11-unix, error=$?"
-	mount --bind /tmp/.X11-unix "$REMASTER_DIR/tmp/.X11-unix" || failure "Cannot bind mount /tmp/.X11-unix in  $REMASTER_DIR/tmp/.X11-unix, error=$?"
+	echo "Creating DBUS uuid"
+	chroot "$REMASTER_DIR" dbus-uuidgen --ensure 1>/dev/null 2>&1
 
 	if [ -e "$REMASTER_HOME/customization-scripts/Xcookie" ] ; then
-		echo "Creating user directory..."
 		UCK_USER_HOME_DIR=`xauth info|grep 'Authority file'| sed "s/[ \t]//g" | sed "s/\/\.Xauthority//" | cut -d ':' -f2`
-		chroot "$REMASTER_DIR" mkdir -p "$UCK_USER_HOME_DIR" || failure "Cannot create user directory, error=$?"
-
-		echo "Copying X authorization file to chroot filesystem..."
-		cat "$REMASTER_HOME/customization-scripts/Xcookie" | chroot "$REMASTER_DIR" xauth -f /root/.Xauthority merge - || failure "Failed to merge X authorization file, error=$?"
-		cat "$REMASTER_HOME/customization-scripts/Xcookie" | chroot "$REMASTER_DIR" xauth merge - || failure "Failed to merge X authorization file in user directory, error=$?"
+		if [ `echo $UCK_USER_HOME_DIR | cut -d '/' -f2` == 'home' ] ; then
+			echo "Creating user directory..."
+			chroot "$REMASTER_DIR" mkdir -p "$UCK_USER_HOME_DIR" >/dev/null 2>&1
+			echo "Copying X authorization file to chroot filesystem..."
+			cat "$REMASTER_HOME/customization-scripts/Xcookie" | chroot "$REMASTER_DIR" xauth -f /root/.Xauthority merge - || failure "Failed to merge X authorization file, error=$?"
+			cat "$REMASTER_HOME/customization-scripts/Xcookie" | chroot "$REMASTER_DIR" xauth merge - || failure "Failed to merge X authorization file in user directory, error=$?"
+		fi
 	fi
 }
 
@@ -256,7 +271,10 @@ function clean_rootfs_after_chroot()
 
 	echo "Removing /home/username directory, if created..."
 	UCK_USER_HOME_DIR=`xauth info|grep 'Authority file'| sed "s/[ \t]//g" | sed "s/\/\.Xauthority//" | cut -d ':' -f2`
-	chroot "$REMASTER_DIR" rm -rf "$UCK_USER_HOME_DIR" # 2>/dev/null
+	if [ `echo $UCK_USER_HOME_DIR | cut -d '/' -f2` == 'home' ] ; then
+		chroot "$REMASTER_DIR" rm -rf "$UCK_USER_HOME_DIR" || failure "Cannot create user directory, error=$?"
+	fi
+	chroot "$REMASTER_DIR" rm -rf /var/lib/dbus/machine-id # 2>/dev/null
 
 	echo "Restoring resolv.conf..."
 	rm -f "$REMASTER_DIR/etc/resolv.conf" || failure "Failed to remove resolv.conf, error=$?"
